5.14 Network-Type
=================

This class describes the type of the network service. The details of
these types are not further elaborated upon in this document.

Type: :py:class:`~otupy.profiles.ctxd.data.network_type.NetworkType` (:py:class:`~otupy.types.base.choice.Choice`)

.. list-table::
   :widths: 3 4 4 3 40
   :header-rows: 1

   * - ID
     - Name
     - Type
     - #
     - Description
   * - 1
     - ethernet
     - Ethernet
     - 1
     - The network type is Ethernet.
   * - 2
     - 802.11
     - 802.11
     - 1
     - The network type is 802.11.
   * - 3
     - 802.15
     - 802.15
     - 1
     - The network type is 802.15.
   * - 4
     - zigbee
     - Zigbee
     - 1
     - The network type is Zigbee.
   * - 5
     - vlan
     - Vlan
     - 1
     - The network type is VLAN.
   * - 6
     - vpn
     - Vpn
     - 1
     - The network type is VPN.
   * - 7
     - lorawan
     - LoRaWAN
     - 1
     - The network type is LoRaWAN.
   * - 8
     - wan
     - Wan
     - 1
     - The network type is WAN.

